Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(386)

Unified Diff: src/compiler/instruction.h

Issue 642883003: [turbofan] Add support for deferred code. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Add cctest Created 6 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/graph-visualizer.cc ('k') | src/compiler/instruction.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/instruction.h
diff --git a/src/compiler/instruction.h b/src/compiler/instruction.h
index 43958b8c6f4e92e0d3a710c05647b3362c6a7590..d3b8a2cab5f0c25ab1a5a2f608039cf7ba1d76ca 100644
--- a/src/compiler/instruction.h
+++ b/src/compiler/instruction.h
@@ -795,7 +795,10 @@ class InstructionBlock FINAL : public ZoneObject {
int32_t code_end() const { return code_end_; }
void set_code_end(int32_t end) { code_end_ = end; }
+ bool IsDeferred() const { return deferred_; }
+
BasicBlock::Id id() const { return id_; }
+ BasicBlock::RpoNumber ao_number() const { return ao_number_; }
BasicBlock::RpoNumber rpo_number() const { return rpo_number_; }
BasicBlock::RpoNumber loop_header() const { return loop_header_; }
BasicBlock::RpoNumber loop_end() const {
@@ -822,12 +825,14 @@ class InstructionBlock FINAL : public ZoneObject {
Predecessors predecessors_;
PhiInstructions phis_;
BasicBlock::Id id_;
+ BasicBlock::RpoNumber ao_number_; // Assembly order number.
// TODO(dcarney): probably dont't need this.
BasicBlock::RpoNumber rpo_number_;
BasicBlock::RpoNumber loop_header_;
BasicBlock::RpoNumber loop_end_;
- int32_t code_start_; // start index of arch-specific code.
- int32_t code_end_; // end index of arch-specific code.
+ int32_t code_start_; // start index of arch-specific code.
+ int32_t code_end_; // end index of arch-specific code.
+ const bool deferred_; // Block contains deferred code.
};
typedef ZoneDeque<Constant> ConstantDeque;
@@ -854,6 +859,10 @@ class InstructionSequence FINAL {
int node_count() const { return static_cast<int>(node_map_.size()); }
+ const InstructionBlocks& instruction_blocks() const {
+ return instruction_blocks_;
+ }
+
int InstructionBlockCount() const {
return static_cast<int>(instruction_blocks_.size());
}
« no previous file with comments | « src/compiler/graph-visualizer.cc ('k') | src/compiler/instruction.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698